#
# spec file for package perl-Test-Refcount
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-Test-Refcount
Version:        0.10
Release:        1.25
%define cpan_name Test-Refcount
Summary:        Assert reference counts on objects
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/P/PE/PEVANS/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Module::Build) >= 0.400400
BuildRequires:  perl(Test::More) >= 0.88
Recommends:     perl(Devel::MAT) >= 0.04
%{perl_requires}

%description
The Perl garbage collector uses simple reference counting during the normal
execution of a program. This means that cycles or unweakened references in
other parts of code can keep an object around for longer than intended. To
help avoid this problem, the reference count of a new object from its class
constructor ought to be 1. This way, the caller can know the object will be
properly DESTROYed when it drops all of its references to it.

This module provides two test functions to help ensure this property holds
for an object class, so as to be polite to its callers.

If the assertion fails; that is, if the actual reference count is different
to what was expected, either of the following two modules may be used to
assist the developer in finding where the references are.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
perl Build.PL installdirs=vendor
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README
%license LICENSE

%changelog
* Thu Jun 27 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.10
  see /usr/share/doc/packages/perl-Test-Refcount/Changes
  0.10    2019-06-26 11:28:13
    [BUGFIXES]
  * Fix unit tests to handle when both Devel::MAT and Devel::FindRef
    are available (RT129908)
    (No module code changes, purely tests)
* Wed Jun 26 2019 Stephan Kulow <coolo@please-enter-an-email-address>
- updated to 0.09
  see /usr/share/doc/packages/perl-Test-Refcount/Changes
  0.09    2019-06-25 21:06:57
    [CHANGES]
  * Add a `refcount()` function that callers can use to build
    refcount-preserving tests
  * Adjust docs to explain more about the Devel::MAT use-case
  * General build file style updates
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.08
  see /usr/share/doc/packages/perl-Test-Refcount/Changes
  0.08    2014/03/27 16:10:38
    [CHANGES]
  * Optional integration with Devel::MAT if available, to heapdump the
    running unit test for later analysis
  0.07    CHANGES:
  * Use pureperl core B module rather than Devel::Refcount, for
    avoiding XS in the deptree of a Test module
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.07
  see /usr/share/doc/packages/perl-Test-Refcount/Changes
  0.07    CHANGES:
  * Use pureperl core B module rather than Devel::Refcount, for
    avoiding XS in the deptree of a Test module
* Thu Mar 24 2011 pascal.bleser@opensuse.org
- initial version (0.06)
